import socket

client = socket.socket(socket.AF_INET, socket.SOCK_STREAM)

def register():
	client.send("USERNAME_REGISTER".encode("utf-8"))
	
	username = input('Username :  ')
	client.send(username.encode("utf-8"))
	
	password = input('Password :  ')
	client.send(password.encode("utf-8"))

def login():
	client.send("USERNAME_LOGIN".encode("utf-8"))

	username = input('Username :  ')
	client.send(username.encode("utf-8"))
	
	password = input('Password :  ')
	client.send(password.encode("utf-8"))

def start_client_socket(host: str, port: int):
	adress = (host, port)
	client.connect(adress)	
	try:
		while True:
			choice = int(input('1. Login\n2. Register\n3. Exit\n\nchoice a number : '))
			if choice == 1:
				login()
			elif choice == 2:
				register()
			
			elif choice == 3:
				client.send('CLIENT_DISCONNECT'.encode("utf-8"))
				exit()
			else:
				print('Wrong number !')
	except KeyboardInterrupt:
		exit()

	finally:
		client.close()


from websockethost.basicCGIserver import startCGIserver
from websockethost.basicserverhttp import start_server_http
from websockethost.socketServerClient.server import start_socket_server
from websockethost.socketServerClient.client import start_client_socket


import sqlite3 as lite

class SqlSys:
    def __init__(self, db_name: str):
        self.conn = lite.connect(db_name)

    def add_User(self, username: str, password: str):
        cursor = self.conn.cursor()
        query = f"INSERT INTO users VALUES(?,?)"
        cursor.execute(query, (username, password))
        self.conn.commit()
        cursor.close()

    def init_database(self, Table_name: str):
        cursor = self.conn.cursor()
        query = f"CREATE TABLE {Table_name} (username TEXT NOT NULL UNIQUE, password TEXT NOT NULL);"
        cursor.execute(query)
        self.conn.commit()
        cursor.close()

    def login_user(self, username, password):
        cursor = self.conn.cursor()
        query = f"SELECT * FROM users WHERE username = ? AND password = ?"
        cursor.execute(query, (username, password))

        if cursor.fetchone():
            cursor.close()
            return 0
        else:
            cursor.close()
            return 1

    def closeDB(self):
        self.conn.close()


import http.server as server
import socketserver
import threading 

def start_server_http(port: int, host: str):
    adress = (host, port)

    handler = server.SimpleHTTPRequestHandler
    httpR = socketserver.TCPServer(adress, handler)
    
    try:        
        print('Server lancer CTRL + C pour arreté le serveur...')
        httpR.serve_forever()
    except KeyboardInterrupt:
        print('Serveur arrété...')


import socket
from websockethost.socketServerClient.ThreadScripts.ThreadForClient import ThreadForClient

server = socket.socket(socket.AF_INET, socket.SOCK_STREAM)

def start_socket_server(host: str, port: int, log_file: str, init_data: bool):
	adress = (host, port)
	server.bind(adress)	
	while True:
		try:
			server.listen(5)
			client, addr = server.accept()
				
			with open(log_file, "a+") as logs:
				logs.write(f"The connection as create on : {addr}")

			my_thread = ThreadForClient(client, add_table=init_data)
			my_thread.start()
			
		except KeyboardInterrupt:
			break

	client.close()
	server.close()



import http.server as server
import socketserver

def startCGIserver(port: int, host: str):
    adress = (host, port)

    handler = server.CGIHTTPRequestHandler
    httpR = socketserver.TCPServer(adress, handler)

    print('Serveur démmaré CTRL + C pour arrété le serveur...')
    try:
        httpR.serve_forever()
    except KeyboardInterrupt:
        print('Serveur CGI arréter...')



from setuptools import find_packages, setup

with open("readme.md", "r") as file:
    long_description = file.read()

setup(
    name="websockethost",
    version="0.1.11",
    description="Web and python socket host (UPD)",
    package={"": ""},
    packages=find_packages(),
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/lamalice20/websockethost",
    author="lamalice20",
    author_email="discord974a@gmail.com",
    install_requires=[""],
    python_requires=">=3.12.5",
)


from websockethost.socketServerClient.SqlSys import SqlSys
import threading

class ThreadForClient(threading.Thread):
	def __init__(self, client, add_table=False):
		threading.Thread.__init__(self)
		self.client = client
		self.add_table = add_table

	def run(self, ):
		db_host = SqlSys("data.db")
		dataMSG = self.client.recv(1024).decode("utf-8")
		if dataMSG == "USERNAME_REGISTER":
			clientUsername = self.client.recv(1024).decode("utf-8")
			clientPassword = self.client.recv(1024).decode("utf-8")
			if self.add_table == True:
				db_host.init_database("users")
			else:
				pass
			db_host.add_User(clientUsername, clientPassword)


		if dataMSG == "USERNAME_LOGIN":
			ClientLoginUsername = self.client.recv(1024).decode("utf-8")
			ClientLoginPassword = self.client.recv(1024).decode("utf-8")
			loginUser = db_host.login_user(ClientLoginUsername, ClientLoginPassword)

			if loginUser == 1:
				self.client.send("nom utilisateur/mot de passe invalide".encode("utf-8"))
			if loginUser == 0:
				self.client.send("Vous êtes connecté ! ".encode("utf-8"))
